Description Usage Arguments Value Author(s) Examples
vkGetToken open web link in browser and generate developer token, which you need for work with vk.com api
1 | vkGetToken(app_id = 5344605)
|
app_id |
Your app id from filed in app page vkontakte. |
R object with vk.com token
Alexey Seleznev
1 2 3 4 5 | ## Not run:
## Get vk api token
myToken <- vkGetToken(app_id = "1")
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.